==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emrcontainers/kotlin/outputs/JobTemplateJobTemplateDataConfigurationOverrides.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emrcontainers.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property applicationConfigurations The configurations for the application running by the job run.
 * @property monitoringConfiguration The configurations for monitoring.
 */
public data class JobTemplateJobTemplateDataConfigurationOverrides(
    public val applicationConfigurations:
    List<JobTemplateJobTemplateDataConfigurationOverridesApplicationConfiguration>? = null,
    public val monitoringConfiguration:
    JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.emrcontainers.outputs.JobTemplateJobTemplateDataConfigurationOverrides):
            JobTemplateJobTemplateDataConfigurationOverrides =
            JobTemplateJobTemplateDataConfigurationOverrides(
                applicationConfigurations = javaType.applicationConfigurations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesApplicationConfiguration.Companion.toKotlin(args0)
                    })
                }),
                monitoringConfiguration = javaType.monitoringConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emrcontainers/kotlin/outputs/JobTemplateJobTemplateDataConfigurationOverrides.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emrcontainers.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property applicationConfigurations The configurations for the application running by the job run.
 * @property monitoringConfiguration The configurations for monitoring.
 */
public data class JobTemplateJobTemplateDataConfigurationOverrides(
    public val applicationConfigurations: List<JobTemplateJobTemplateDataConfigurationOverridesApplicationConfiguration>? = null,
    public val monitoringConfiguration: JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emrcontainers.outputs.JobTemplateJobTemplateDataConfigurationOverrides): JobTemplateJobTemplateDataConfigurationOverrides =
            JobTemplateJobTemplateDataConfigurationOverrides(
                applicationConfigurations = javaType.applicationConfigurations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesApplicationConfiguration.Companion.toKotlin(args0)
                    })
                }),
                monitoringConfiguration = javaType.monitoringConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.emrcontainers.kotlin.outputs.JobTemplateJobTemplateDataConfigurationOverridesMonitoringConfiguration.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
